@@ -9,15 +9,15 @@ from typing import Any, List
 import attr
 
 try:
-    import toml
+    import tomli
 except ImportError:  # pragma: no cover
-    toml = None  # type: ignore
+    tomli = None  # type: ignore
 
 from scriv.literals import find_literal
 
 
 @attr.s
-class Config:
+class _Options:
     """
     All the settable options for Scriv.
     """
@@ -171,25 +171,46 @@ class Config:
         },
     )
 
-    def __attrs_post_init__(
-        self,
-    ):  # noqa: D105 (Missing docstring in magic method)
-        self.resolve_all()
+    # Glob for files in the fragments directory that should not be collected.
+    skip_fragments = attr.ib(
+        type=str,
+        default="README.*",
+        metadata={
+            "doc": """\
+                A glob pattern for files in the fragment directory that should
+                not be collected.
+                """,
+        },
+    )
 
-    def resolve_all(self):
-        """
-        Prepare all fields in the config.
 
-        Call resolve_value on them, and convert strings to lists as needed.
-        """
-        for attrdef in attr.fields(Config):
-            value = getattr(self, attrdef.name)
-            if attrdef.type is list:
-                if isinstance(value, str):
-                    value = convert_list(value)
-            else:
-                value = self.resolve_value(value)
-            setattr(self, attrdef.name, value)
+class Config:
+    """
+    Configuration for Scriv.
+
+    All the settable options for Scriv, with resolution of values within other
+    values.
+
+    """
+
+    def __init__(self, **kwargs):
+        """All values in _Options can be set as keywords."""
+        self._options = _Options(**kwargs)
+
+    def __getattr__(self, name):
+        """Proxy to self._options, and resolve the value."""
+        fields = attr.fields_dict(_Options)
+        if name not in fields:
+            raise AttributeError(f"Scriv configuration has no {name!r} option")
+        attrdef = fields[name]
+        value = getattr(self._options, name)
+        if attrdef.type is list:
+            if isinstance(value, str):
+                value = convert_list(value)
+        else:
+            value = self.resolve_value(value)
+        setattr(self, name, value)
+        return value
 
     @classmethod
     def read(cls) -> "Config":
@@ -210,7 +231,6 @@ class Config:
         config.read_one_config(
             str(Path(config.fragment_directory) / "scriv.ini")
         )
-        config.resolve_all()
         return config
 
     def read_one_config(self, configfile: str) -> None:
@@ -224,13 +244,13 @@ class Config:
             (name for name in section_names if parser.has_section(name)), None
         )
         if section_name:
-            for attrdef in attr.fields(Config):
+            for attrdef in attr.fields(_Options):
                 try:
                     val = parser[section_name][attrdef.name]  # type: Any
                 except KeyError:
                     pass
                 else:
-                    setattr(self, attrdef.name, val)
+                    setattr(self._options, attrdef.name, val)
 
     def read_one_toml(self, tomlfile: str) -> None:
         """
@@ -242,7 +262,7 @@ class Config:
 
         toml_text = tomlpath.read_text()
 
-        if toml is None:
+        if tomli is None:
             # Toml support isn't installed. Only print an exception if the
             # config file seems to have settings for us.
             has_scriv = re.search(r"(?m)^\[tool\.scriv\]", toml_text)
@@ -254,19 +274,19 @@ class Config:
                 raise Exception(msg)
         else:
             # We have toml installed, parse the file and look for our settings.
-            data = toml.loads(toml_text)
+            data = tomli.loads(toml_text)
             try:
                 scriv_data = data["tool"]["scriv"]
             except KeyError:
                 # No settings for us
                 return
-            for attrdef in attr.fields(Config):
+            for attrdef in attr.fields(_Options):
                 try:
                     val = scriv_data[attrdef.name]
                 except KeyError:
                     pass
                 else:
-                    setattr(self, attrdef.name, val)
+                    setattr(self._options, attrdef.name, val)
 
     def resolve_value(self, value: str) -> str:
         """
@@ -280,7 +300,7 @@ class Config:
             "literal:" read a literal string from a file.
 
         """
-        value = value.replace("${config:format}", self.format)
+        value = value.replace("${config:format}", self._options.format)
         if value.startswith("file:"):
             file_name = value.partition(":")[2].strip()
             file_path = Path(self.fragment_directory) / file_name
